/* 
 * noIdle header file v0.5
 * 
 * (C) 2002 - Jos Martins (jemart@student.dei.uc.pt)
 * 
 * */

#ifndef __NOIDLE_H__
#define __NOIDLE_H__

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include <ctype.h>
#include <signal.h>
#include <errno.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>

#define IDLE 0
#define NOIDLE 1
#define MAX_LINE 1024

/* This are the only two variables that you have to change. The cicle time and
   the idle time. */
#define CICLE_TIME 120 /* seconds (2 minutes, but 900seg=15min if it helps) */
#define IDLE_TIME 30 /* minutes */

#define DO_DATE 1
#define DONOT_DATE 0

#define CMD_W 0
#define CMD_PS 1
#define CMD_WHOAMI 3

#define OPC_DEFAULT 0
#define OPC_VERSAO 1
#define OPC_HELP 2
#define OPC_LOGFILE 4
#define OPC_4 8
#define OPC_5 16

#define LOG_FILE "noIdle.log"
#define LOG_PERM "a"

#define VERSION "1.22b"
#define BUILD "28-Apr-2002"

/* for parsing debug*/
/*#define DEBUG*/

/* process information struct */
typedef struct my_process{
  char name[MAX_LINE];
  char tty[MAX_LINE];
  int pid;
  int idle;
}process;

/* 
 * Sets and initializes some things before start...
 * */
int firstAssignments(void);

/* 
 * Process the arguments passed.
 * */
int processArgs(int arg_num,char **arg_arr);

/* 
 * Gets the curent process information.
 * */
int processCmd(int cmd, char *arg0, char *arg1);

/* 
 * Reads from pipe and place string in arg0.
 * */
int read_pipe_fd(char *arg0);

/* 
 * Checks if the string <str> (obtained from processStatus) has intormation
 * about a idle process.
 * */
int checkIdle(char *str);

/* 
 * Prints a message in the log file. May print in stdout if the option of no
 * log file was passed. The date may be DO_DATE or DONOT_DATE to print the
 * date or not, respectively.
 * */
void printMsg(int date,char *msg);

/* 
 * Signal catching...
 * */
int assignSignals(void);

/* 
 * Copy into <tok> the token number <tokNum> from string <str> since <offs>.
 * */
int getToken(int tokNum, char *tok, char *str, int *offs);

/* 
 * Catched function.
 * */
void panicExit(int signal);

#endif /* __NOIDLE_H__ */
